<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  			$messaggio = "Insérez les prix pour l'année"; break;
case "Prezzi della":  							$messaggio = "Prix de"; break;
case "tariffa":  								$messaggio = "tarif"; break;
case "soprannominata":  						$messaggio = "appelé"; break;
case "Dal":  									$messaggio = "De"; break;
case "al":  									$messaggio = "à"; break;
case "inserisci i nuovi prezzi":  				$messaggio = "Inserez les nouveaux prix"; break;
case "modifica i prezzi già inseriti":  		$messaggio = "modifiez les prix déjà insérés"; break;
case "Costi aggiuntivi":  						$messaggio = "Surcoûts"; break;
case "Nome del nuovo costo aggiuntivo":			$messaggio = "Nouveau nom du surcoût "; break;
case "da applicare":  							$messaggio = "à appliquer"; break;
case "sempre":  								$messaggio = "toujours"; break;
case "su richiesta":  							$messaggio = "sur demande"; break;
case "chiedi per quanto deve essere moltiplicato":				$messaggio = "demandez par combien il doit être multiplié"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "considérez ce coût simple pour lit supplémentaire(s)"; break;
case "numero di settimane":  					$messaggio = "nombre de semaines"; break;
case "numero di giorni":  						$messaggio = "nombre de jours"; break;
case "tutte":  									$messaggio = "toutes"; break;
case "tutti":  									$messaggio = "tous"; break;
case "tutte meno una":  						$messaggio = "toutes moins une"; break;
case "tutti meno uno":  						$messaggio = "tout moins un"; break;
case "chiedere":  								$messaggio = "demandez"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "considérez ce coût hebdomadaire par lit(s) supplémentaire(s)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "considérez ce coût journalier par lit(s) supplémentaire(s)"; break;
case "della tariffa arrotondato a":  			$messaggio = "du prix arrondi à"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "considérez ce coût en pourcentage pour lit supplémentaire(s)"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Insérez le nouveau surcoût"; break;
case "Caparra":  								$messaggio = "Accompte"; break;
case "arrotondata a":  							$messaggio = "arrondi à"; break;
case "Inserisci o modifica la caparra":  		$messaggio = "Insérez ou modifier l'acompte"; break;
case "Vedi i prezzi già inseriti":  			$messaggio = "Voir les prix déjà insérés"; break;
case "Torna al menù principale":  				$messaggio = "Retour au menu principal"; break;
case "Si deve inserire la percentuale":  		$messaggio = "Vous devez insérer le pourcentage"; break;
case "La caparra è stata modificata":  			$messaggio = "L'acompte a été modifié"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "Vous devez choisir comment appliquer le coût simple"; break;
case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "Vous devez insérer le nom du surcoût"; break;
case "Il costo aggiuntivo finale":  			$messaggio = "Le surcoût simple"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "il existe déjà, allez à la page de visualisation des périodes et tarifs pour le supprimer"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "Demander par combien il doit être multiplié le surcoût simple ne doit pas être appliqué automatiquement"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "vous devez choisir comment appliquer le coût hedomadaire"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "vous devez choisir comment appliquer le coût quotidien"; break;
case "e il numero di settimane":  				$messaggio = "et le nombre de semaines"; break;
case "e il numero di giorni":  					$messaggio = "et le nombre de jours"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "Demander le nombre de semaines ou par combien il doit être multiplié le surcoût hebdomadaire ne doit pas être appliqué automatiquement"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "Demander le nombre de jours ou par combien il doit être multiplié le surcoût quotidien ne doit pas être appliqué automatiquement"; break;
case "Il costo aggiuntivo settimanale":  		$messaggio = "Le surcoût hebdomadaire";; break;
case "Il costo aggiuntivo giornaliero":  		$messaggio = "Le surcoût quotidien"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "Vous devez choisir comment appliquer le coût en pourcentage"; break;
case "e il valore dell'arrotondamento":			$messaggio = "et la valeur arrondie à"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "Demander par combien il doit être multiplié le surcoût de pourcentage ne doit pas être appliqué automatiquement"; break;
case "Il costo aggiuntivo percentuale":			$messaggio = "le surcoût de pourcentage"; break;
case "è stato inserito":  						$messaggio = "il a été inséré"; break;
case "Nessun dato è stato inserito":  			$messaggio = "aucune donnée n'a été insérée"; break;
case "Il soprannome della":  					$messaggio = "Le surnom de"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "existe déjà, utilisez le bouton \"modifiez les prix déjà insérés\" pour le changer, ou ne l'insérez pas aux prix d'insertion dans de nouvelles périodes"; break;
case "Il soprannome":  							$messaggio = "Le surnom"; break;
case "già esiste, ne devi usare un'altro":  	$messaggio = "existe déjà, choisissez en un autre"; break;
case "Le date del periodo numero":  			$messaggio = "Les dates du nombre de période"; break;
case "sono sbagliate":  						$messaggio = "sont faux"; break;
case "Il periodo":  							$messaggio = "La période"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "il se superpose à une période précédente"; break;
case "Un prezzo nel periodo numero":  			$messaggio = "Un prix de la période numéro"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":	$messaggio = "existe déjà, utilisez le bouton \"modifiez les prix déjà insérés\" pour le changer"; break;
case "è stato cambiato":  						$messaggio = "il a été changé"; break;
case "Il prezzo del periodo":  					$messaggio = "Le prix de la période"; break;
case "è stato inserito":  						$messaggio = "il a été inséré"; break;
case "Il prezzo del periodo numero":  			$messaggio = "Le prix de la période numéro"; break;
case "è sbagliato":  							$messaggio = "est faux"; break;
case "I soldi del costo finale sono sbagliati":			$messaggio = "L'argent pour le coût simple est erroné"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "L'argent pour le coût hebdomadaire est erroné"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "L'argent pour le coût journalier est erroné"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "L'argent pour le coût de pourcentage est erroné"; break;
case "Inserzione per settimane":  				$messaggio = "Insertion sur la base hebdomadaire"; break;
case "Settimane dal":  							$messaggio = "Semaines de"; break;
case "Dom/Lun":  								$messaggio = "Dim/Lun"; break;
case "Lun/Mar":  								$messaggio = "Lun/Mar"; break;
case "Mar/Mer":  								$messaggio = "Mar/Mer"; break;
case "Mer/Gio":  								$messaggio = "Mer/Jeu"; break;
case "Gio/Ven":  								$messaggio = "Jeu/Ven"; break;
case "Ven/Sab":  								$messaggio = "Ven/Sam"; break;
case "Sab/Dom":  								$messaggio = "Sam/Dim"; break;
case "inserisci o modifica i prezzi":  			$messaggio = "insérez ou modifiez les prix"; break;
case "Le date sono sbagliate":  				$messaggio = "Les dates sont erronées"; break;
case "Il formato dei soldi è sbagliato":  		$messaggio = "Le format monétaire est erroné"; break;
case "I prezzi per le settimane dal":  			$messaggio = "Les prix pour les semaines de"; break;
case "della <b>tariffa":  						$messaggio = "du <b>tarif"; break;
case "sono stati inseriti":  					$messaggio = "ils ont été insérés"; break;
case "si":  									$messaggio = "oui"; break;
case "no":  					$messaggio = "no"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "attribué automatiquement avec des tarifs"; break;
case "nessuna":  								$messaggio = "personne"; break;
case "scegliere":  								$messaggio = "choisissez"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "montrer dans la page d'insertion des réservations"; break;
case "Torna indietro":  						$messaggio = "Retournez"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":		$messaggio = "Choisissez les prix auxquels vous appliquez automatiquement un <b>simple</b> surcoût"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Choisissez les prix auxquels vous appliquez automatiquement un surcoût <b>hebdomadaire</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Choisissez les prix auxquels vous appliquez automatiquement un surcoût <b>quotidien</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Choisissez les tarifs auxquels vous appliquez automatiquement un surcoût en <b>pourcentage</b>"; break;
case "Continua":  								$messaggio = "Continuez"; break;
case "Tipo di costo aggiuntivo":  				$messaggio = "Type de surcoût"; break;
case "unico":  									$messaggio = "unique"; break;
case "settimanale":  							$messaggio = "hebdomadaire"; break;
case "giornaliero":  							$messaggio = "journalier"; break;
case "il prezzo totale":  						$messaggio = "le prix total"; break;
case "la caparra":  							$messaggio = "l'acompte"; break;
case "totale meno caparra":  					$messaggio = "total sans l'acompte"; break;
case "esattamente":  							$messaggio = "exactement"; break;
case "settimane":  								$messaggio = "semaines"; break;
case "giorni":  								$messaggio = "jours"; break;
case "Se possibile":  							$messaggio = "Si possible"; break;
case "Sempre":  								$messaggio = "Toujours"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Associé aux semaines spécifiques de la réservation"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Associé aux jours spécifiques de la réservation"; break;
case "Tutte":  									$messaggio = "Toutes"; break;
case "Tutti":  									$messaggio = "Tous"; break;
case "Tutte meno":  							$messaggio = "Toutes moins"; break;
case "Tutti meno":  							$messaggio = "Tous moins"; break;
case "la prima":  								$messaggio = "le premier"; break;
case "il primo":  								$messaggio = "le premier"; break;
case "l'ultima":  								$messaggio = "le dernier"; break;
case "l'ultimo":  								$messaggio = "le dernier"; break;
case "Chiedere":  								$messaggio = "Demandez"; break;
case "settimane sì":  							$messaggio = "semaines oui"; break;
case "giorni sì":  								$messaggio = "jours oui"; break;
case "settimane no":  							$messaggio = "semainess non"; break;
case "giorni no":  								$messaggio = "jours non"; break;
case "e":  										$messaggio = "et"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Jours de la semaine sélectionnés"; break;
case "Lunedì":  								$messaggio = "Lundi"; break;
case "Martedì":  								$messaggio = "Mardi"; break;
case "Mercoledì":  								$messaggio = "Mercredi"; break;
case "Giovedì":  								$messaggio = "Jeudi"; break;
case "Venerdì":  								$messaggio = "Vendredi"; break;
case "Sabato":  								$messaggio = "Samedi"; break;
case "Domenica":  								$messaggio = "Dimanche"; break;
case "Moltiplicare il costo per":  				$messaggio = "Multipliez le coût par"; break;
case "Uno":  									$messaggio = "Un"; break;
case "Chiedere":  								$messaggio = "Demandez"; break;
case "Numero di persone":  						$messaggio = "Nombre de personnes"; break;
case "Numero di persone totale":  						$messaggio = "Nombre de personnes total"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "à l'exclusion de ceux des coûts avec les lits supplémentaires"; break;
case "Periodi in cui è permesso inserire il costo":		$messaggio = "Périodes où il est permis d'insérer le coût"; break;
case "In tutti":  								$messaggio = "Tous"; break;
case "Solo nei periodi selezionati":  			$messaggio = "Seulement dans les périodes sélectionnées"; break;
case "dal":  									$messaggio = "de"; break;
case "Elimina un periodo":  					$messaggio = "Période supprimée"; break;
case "Aggiungi un periodo":  					$messaggio = "Ajouter une période"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":		$messaggio = "si toutes les semaines de la réservation ont lieu dans les périodes choisies"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":			$messaggio = "si tous les jours de la réservation ont lieu dans les périodes choisies"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "si même seulement une semaine de la réservation a lieu dans les périodes choisies"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":		$messaggio = "si même seulement un jour de la réservation a lieu dans les périodes choisies"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":			$messaggio = "appliquez-vous le coût seulement aux semaines autorisées dans la réservation"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":				$messaggio = "appliquez-vous le coût seulement aux jours autorisés dans la réservation"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":				$messaggio = "Caractéristiques du coût à maintenir lorsque une modification de réservation"; break;
case "Valore percentuale":  					$messaggio = "Valeur en pourcentage"; break;
case "e settimane associate":  					$messaggio = "et semaines associées"; break;
case "e giorni associati":  					$messaggio = "et jours associés"; break;
case "Assegnazione settimane":  				$messaggio = "Attribution semaines"; break;
case "Assegnazione giorni":  					$messaggio = "Attribution jours"; break;
case "Numero per cui viene moltiplicato":	  	$messaggio = "Nombre par lequel il est multiplié"; break;
case "Periodi permessi":  						$messaggio = "Périodes autorisées"; break;
case "Associazione alle tariffe":  				$messaggio = "Association aux tarifs"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Montrer dans la page d'insertion les réservations"; break;
case "Si":  									$messaggio = "Oui"; break;
case "No":  									$messaggio = "Non"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "A considérer le coût supplementire pour lit(s) suppémentaire(s)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Limiter le nombre qui est possible à avoir en même temps dans une même période"; break;
case "Valore del costo":  						$messaggio = "Valeur du coût"; break;
case "fisso di":  								$messaggio = "fixer de"; break;
case "percentuale su":  						$messaggio = "pourcentage dessus"; break;
case "la tariffa":  							$messaggio = "le tarif"; break;
case "indietro":  								$messaggio = "en arrière"; break;
case "avanti":  								$messaggio = "en avant"; break;
case "del":  									$messaggio = "de"; break;
case "arrotondato a":  							$messaggio = "arrondi à"; break;
case "Errore nei valori inseriti":  			$messaggio = "Erreur dans les valeurs insérées"; break;
case "Assegnare automaticamente con le tariffe selezionate":	$messaggio = "Assigner automatiquement avec les tarifs sélectionnés"; break;
case "Tariffe":  								$messaggio = "Tarifs"; break;
case "Il costo aggiuntivo":  					$messaggio = "Le surcoût suppémentaire"; break;
case "OK":  									$messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":	$messaggio = "Les semaines à appliquer le coût"; break;
case "I giorni a cui applicare il costo":		$messaggio = "Les jours à appliquer le coût"; break;
case "uno":  									$messaggio = "un"; break;
case "NO":  									$messaggio = "NON"; break;
case "SI":  									$messaggio = "OUI"; break;
case "Tariffe incompatibili con il costo":  	$messaggio = "Tarifs incompatibles avec le coût"; break;
case "Tariffe incompatibili":  					$messaggio = "Tarifs incompatibles"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "or more reservations are inserted contemporarely"; break;
case "è":  					$messaggio = "is"; break;
case "il":  					$messaggio = "the"; break;
case "sono":  					$messaggio = "are"; break;
case "Sulla":  					$messaggio = "On"; break;
case "p":  					$messaggio = "p"; break;
case "Se":  					$messaggio = "If"; break;
case "Se si inseriscono":  			$messaggio = "If"; break;
case "a":  					$messaggio = "to"; break;
case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
case "Inserzione per giorni":			$messaggio = "Insertion on daily basis"; break;
case "Inserzione per settimane":  		$messaggio = "Insertion on weekly basis"; break;
case "minimo":  				$messaggio = "minimum"; break;
case "massimo":  				$messaggio = "maximum"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
case "i prezzi della":  			$messaggio = "the prices to"; break;
case "dalla":  					$messaggio = "from"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "The prices of the selected rate have been imported"; break;
case "importa":  				$messaggio = "import"; break;
case "se selezionato mantenere anche":  	$messaggio = "if selected keep also"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "When possible assign automatically if"; break;
case "meno di":  				$messaggio = "less than"; break;
case "più di":  				$messaggio = "more than"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "days are remaining from the starting date of the reservation when it is inserted"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "When possible assign automatically if"; break;
case "Modifica il costo":  			$messaggio = "Modify the cost"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":	$messaggio = "Insert a new extra cost called"; break;
case "importando le caratteristiche da":	$messaggio = "importing settings from"; break;
case "Sempre in periodi permessi":  		$messaggio = "Always in allowed periods"; break;
case "Prezzo dell'intera settimana":  		$messaggio = "Price of entire week"; break;
case "Prezzi dei giorni":  			$messaggio = "Prices of days"; break;
case "tra":  					$messaggio = "between"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":	$messaggio = "Inventory items to delete when the cost is inserted"; break;
case "Nessuno":  				$messaggio = "No one"; break;
case "Beni selezionati":  			$messaggio = "Selected items"; break;
case "Aggiungi un bene":  			$messaggio = "Add an item"; break;
case "Elimina un bene":  			$messaggio = "Delete an item"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Delete items from inventory of stockroom"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Inventory items to delete"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
case "Il tipo di applicazione della":  		$messaggio = "The enforcement type of"; break;
case "per persona":  				$messaggio = "per person"; break;
case "per settimana":  				$messaggio = "per week"; break;
case "per giorno":  				$messaggio = "per day"; break;
case "La caparra è errata":  			$messaggio = "The deposit is wrong"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
case "della tariffa":  				$messaggio = "of the rate"; break;
case "Inserisci o modifica le tasse":  		$messaggio = "Insert or modify taxes"; break;
case "Le commissioni sono state modificate":  	$messaggio = "Commissions have been modified"; break;
case "Le commissioni sono errate":  		$messaggio = "Commissions are wrong"; break;
case "Le tasse sono state modificate":  	$messaggio = "Taxes have been modified"; break;
case "Le tasse sono errate":  			$messaggio = "Taxes are wrong"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "All rate prices are considered as already including taxes"; break;
case "Inserisci o modifica le commissioni normali":  	$messaggio = "Insert or modify the normal commissions"; break;
case "Inserisci o modifica le commissioni in questo periodo":  	$messaggio = "Insert or modify commissions in this period"; break;
case "al giorno":  				$messaggio = "per day"; break;
case "alla settimana":  			$messaggio = "per week"; break;
case "il valore del costo si intente con tasse già incluse":	$messaggio = "the cost value is considered as already including taxes"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "the rate price for the first"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "the rate price for the first"; break;
case "della":  					$messaggio = "of the"; break;
case "tariffa + sconto":  			$messaggio = "rate + discount"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "rate + discount + extra costs"; break;
case "della tar.":  				$messaggio = "of rate"; break;
case "di t.+s.":  				$messaggio = "of r.+d."; break;
case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
case "Nome della":  				$messaggio = "Name of"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "prezzo per settimana":  			$messaggio = "price per week"; break;
case "prezzo per giorno":  			$messaggio = "price per day"; break;
case "prezzo per persona per settimana":  	$messaggio = "price per person per week"; break;
case "prezzo per persona per giorno":  		$messaggio = "price per person per day"; break;
case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
case "Numero massimo":  			$messaggio = "Maximum number"; break;
case "0 se illimitato":  			$messaggio = "0 for unlimited"; break;
case "meno":  					$messaggio = "minus"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "the cost will be multiplied by zero if the sum is negative"; break;
case "Combina con altri costi":			$messaggio = "Combine with other costs"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Costi combinati":  			$messaggio = "Combined costs"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Fast insertion of a new extra cost for"; break;
case "permanenza minima":  			$messaggio = "minimum stay"; break;
case "numero di neonati":  			$messaggio = "number of infants"; break;
case "letto aggiuntivo":  			$messaggio = "extra bed"; break;
case "offerta speciale":  			$messaggio = "special offer"; break;
case "inserisci":  				$messaggio = "insert"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; break;
case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
case "Valore dello sconto":  			$messaggio = "Discount value"; break;
case "del prezzo totale":  			$messaggio = "of total price"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "If the reservation length is"; break;
case "o più giorni":  				$messaggio = "days or more"; break;
case "Importa ora":  				$messaggio = "Import now"; break;
case "Importa sempre":  			$messaggio = "Always import"; break;
case "cancella":  				$messaggio = "delete"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
case "al prezzo per persona":  			$messaggio = "to per person price"; break;
case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
case "La tariffa":  				$messaggio = "The rate"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
case "tutte le tariffe":  			$messaggio = "all rates"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
case "modifica":  				$messaggio = "modify"; break;
case "In modo predefinito importa":  		$messaggio = "By default import"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
case "escludi":  				$messaggio = "exclude"; break;
case "includi solo":  				$messaggio = "include only"; break;
case "questi tipi":  				$messaggio = "these types"; break;
case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
case "tariffe con":  				$messaggio = "rates with"; break;
case "per persona nullo":  			$messaggio = "per person zero"; break;
case "fisso nullo":  				$messaggio = "fixed zero"; break;
case "da per persona":  			$messaggio = "from per person"; break;
case "più fisso":  				$messaggio = "from fixed"; break;
case "dal fisso":  				$messaggio = "plus fixed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>